@@ -129,12 +129,12 @@ typedef struct {
  *	2		sleep on/off
  */
 static delay_info_t delay_info[] = {
-	{ DELAY_R_W_D,	   DELAY_SET_ACTION(DELAY_S, DELAY_S, DELAY_D), 1.0 },
-	{ DELAY_D_R_W,	   DELAY_SET_ACTION(DELAY_D, DELAY_S, DELAY_S), 1.0 },
-	{ DELAY_R_D_W,     DELAY_SET_ACTION(DELAY_S, DELAY_D, DELAY_S), 1.0 },
-	{ DELAY_D_R_D_W,   DELAY_SET_ACTION(DELAY_D, DELAY_D, DELAY_S), 2.0 },
-	{ DELAY_R_D_W_D,   DELAY_SET_ACTION(DELAY_S, DELAY_D, DELAY_D), 2.0 },
-	{ DELAY_D_R_D_W_D, DELAY_SET_ACTION(DELAY_D, DELAY_D, DELAY_D), 3.0 },
+	{ 1.0, DELAY_R_W_D,	DELAY_SET_ACTION(DELAY_S, DELAY_S, DELAY_D) },
+	{ 1.0, DELAY_D_R_W,	DELAY_SET_ACTION(DELAY_D, DELAY_S, DELAY_S) },
+	{ 1.0, DELAY_R_D_W,     DELAY_SET_ACTION(DELAY_S, DELAY_D, DELAY_S) },
+	{ 2.0, DELAY_D_R_D_W,   DELAY_SET_ACTION(DELAY_D, DELAY_D, DELAY_S) },
+	{ 2.0, DELAY_R_D_W_D,   DELAY_SET_ACTION(DELAY_S, DELAY_D, DELAY_D) },
+	{ 3.0, DELAY_D_R_D_W_D, DELAY_SET_ACTION(DELAY_D, DELAY_D, DELAY_D) },
 };
 
 /* scaling factor */
